function babelPluginTransformFsPromises(babel) {
    var t = babel.types;
    var moduleNames = new Set([
        "fs/promises",
        "node:fs/promises"
    ]);
    var generateImportSourceStringLiteral = function(source) {
        var moduleName = source.replace(/\/promises$/, "").replace(/^node:/, "");
        return t.stringLiteral(moduleName);
    };
    return {
        name: "transform-fs-promises",
        visitor: {
            CallExpression: function(path) {
                var node = path.node;
                if (t.isIdentifier(node.callee, {
                    name: "require"
                }) && 1 === node["arguments"].length && t.isStringLiteral(node["arguments"][0]) && moduleNames.has(node["arguments"][0].value)) path.replaceWith(t.memberExpression(t.callExpression(t.identifier("require"), [
                    generateImportSourceStringLiteral(node["arguments"][0].value)
                ]), t.identifier("promises")));
                if ((t.isImport(node.callee) || t.isIdentifier(node.callee, {
                    name: "import"
                })) && 1 === node["arguments"].length && t.isStringLiteral(node["arguments"][0]) && moduleNames.has(node["arguments"][0].value)) {
                    var internalIdentifier = path.scope.generateUidIdentifier("esModule");
                    path.replaceWith(t.callExpression(t.memberExpression(t.callExpression(t.identifier("import"), [
                        generateImportSourceStringLiteral(node["arguments"][0].value)
                    ]), t.identifier("then")), [
                        t.arrowFunctionExpression([
                            internalIdentifier
                        ], t.memberExpression(internalIdentifier, t.identifier("promises")))
                    ]));
                }
            },
            ImportDeclaration: function(path) {
                var node = path.node;
                if (moduleNames.has(node.source.value) && 1 === node.specifiers.length && t.isImportDefaultSpecifier(node.specifiers[0])) {
                    var localName = node.specifiers[0].local.name;
                    path.replaceWith(t.importDeclaration([
                        t.importSpecifier(t.identifier(localName), t.identifier("promises"))
                    ], generateImportSourceStringLiteral(node.source.value)));
                }
                if (moduleNames.has(node.source.value) && node.specifiers.some(function(spec) {
                    return t.isImportSpecifier(spec);
                })) {
                    var namesSpecifiers = node.specifiers.filter(function(spec) {
                        return t.isImportSpecifier(spec);
                    });
                    var defaultSpec = node.specifiers.find(function(spec) {
                        return t.isImportDefaultSpecifier(spec);
                    });
                    var localPromises = path.scope.generateUidIdentifier("promises");
                    path.replaceWithMultiple([
                        t.importDeclaration([
                            defaultSpec,
                            t.importSpecifier(localPromises, t.identifier("promises"))
                        ].filter(Boolean), generateImportSourceStringLiteral(node.source.value)),
                        t.variableDeclaration("const", [
                            t.variableDeclarator(t.objectPattern(namesSpecifiers.map(function(spec) {
                                return t.objectProperty(spec.local, spec.imported, false, true);
                            })), localPromises)
                        ])
                    ]);
                }
                if (moduleNames.has(node.source.value) && 1 === node.specifiers.length && t.isImportNamespaceSpecifier(node.specifiers[0])) path.replaceWith(t.importDeclaration([
                    t.importSpecifier(node.specifiers[0].local, t.identifier("promises"))
                ], generateImportSourceStringLiteral(node.source.value)));
            },
            ExportAllDeclaration: function(path) {
                var node = path.node;
                if (moduleNames.has(node.source.value)) {
                    var localPromises = path.scope.generateUidIdentifier("promises");
                    path.replaceWithMultiple([
                        t.importDeclaration([
                            t.importSpecifier(localPromises, t.identifier("promises"))
                        ], generateImportSourceStringLiteral(node.source.value)),
                        t.exportDefaultDeclaration(localPromises)
                    ]);
                }
            },
            ExportNamedDeclaration: function(path) {
                var _node_source;
                var node = path.node;
                if (moduleNames.has(null === (_node_source = node.source) || void 0 === _node_source ? void 0 : _node_source.value) && node.specifiers.some(function(spec) {
                    return t.isExportSpecifier(spec);
                })) {
                    var namesSpecifiers = node.specifiers.filter(function(spec) {
                        return t.isExportSpecifier(spec);
                    });
                    var defaultSpec = node.specifiers.find(function(spec) {
                        return t.isExportDefaultSpecifier(spec);
                    });
                    var localPromises = path.scope.generateUidIdentifier("promises");
                    var specUidIdentifierMap = new Map();
                    path.replaceWithMultiple([
                        t.importDeclaration([
                            defaultSpec ? t.importDefaultSpecifier(t.identifier(defaultSpec.exported.name)) : void 0,
                            t.importSpecifier(localPromises, t.identifier("promises"))
                        ].filter(Boolean), generateImportSourceStringLiteral(node.source.value)),
                        t.variableDeclaration("const", [
                            t.variableDeclarator(t.objectPattern(namesSpecifiers.map(function(spec) {
                                var UidIdentifier = path.scope.generateUidIdentifier(spec.local.name);
                                specUidIdentifierMap.set(spec, UidIdentifier);
                                return t.objectProperty(spec.local, UidIdentifier, false, false);
                            })), localPromises)
                        ]),
                        t.exportNamedDeclaration(null, namesSpecifiers.map(function(spec) {
                            return t.exportSpecifier(spec.local, specUidIdentifierMap.get(spec));
                        })),
                        defaultSpec ? defaultSpec : null
                    ].filter(Boolean));
                }
            }
        }
    };
}
var src_rslib_entry_ = babelPluginTransformFsPromises;
export { babelPluginTransformFsPromises, src_rslib_entry_ as default };

//# sourceMappingURL=index.mjs.map